<!DOCTYPE html>
<html>
    {% load pages assets html %}
    <head>

        <meta charset="utf-8">
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
        {# <meta name="keywords" content="{% block meta_keywords %}{% meta_keywords %}{% endblock %}"> #}
        <meta name="description" content="{% block meta_description %}{% meta_description %}{% endblock %}">
        <meta name="robots" content="{% block meta_robots %}{% meta_robots %}{% endblock %}">
        <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no" />
        <link rel="canonical" href="http{% if request.is_secure %}s{% endif %}://{{ request.META.HTTP_HOST }}{{ request.path }}" />

        <title>{% block title %}{% title %}{% endblock %}</title>

        {% block feeds %}{% endblock %}

        {% stylesheet %}

        <!--[if lt IE 9]>
            <script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script>
        <![endif]-->

        {% script %}

    </head>

    <body class="{% block body_class %}{% endblock %}">

        <!--[if lt IE 8]>  <div style='border: 1px solid #F7941D; background: #FEEFDA; text-align: center; clear: both; height: 75px; position: relative;'>    <div style='position: absolute; right: 3px; top: 3px; font-family: courier new; font-weight: bold;'><a href='#' onclick='javascript:this.parentNode.parentNode.style.display="none"; return false;'><img src='http://www.ie6nomore.com/files/theme/ie6nomore-cornerx.jpg' style='border: none;' alt='Close this notice'/></a></div>    <div style='width: 640px; margin: 0 auto; text-align: left; padding: 0; overflow: hidden; color: black;'>      <div style='width: 75px; float: left;'><img src='http://www.ie6nomore.com/files/theme/ie6nomore-warning.jpg' alt='Warning!'/></div>      <div style='width: 275px; float: left; font-family: Arial, sans-serif;'>        <div style='font-size: 14px; font-weight: bold; margin-top: 12px;'>You are using an outdated browser</div>        <div style='font-size: 12px; margin-top: 6px; line-height: 12px;'>For a better experience using this site, please upgrade to a modern web browser.</div>      </div>      <div style='width: 75px; float: left;'><a href='http://www.firefox.com' target='_blank'><img src='http://www.ie6nomore.com/files/theme/ie6nomore-firefox.jpg' style='border: none;' alt='Get Firefox 3.5'/></a></div>      <div style='width: 75px; float: left;'><a href='http://www.browserforthebetter.com/download.html' target='_blank'><img src='http://www.ie6nomore.com/files/theme/ie6nomore-ie8.jpg' style='border: none;' alt='Get Internet Explorer 8'/></a></div>      <div style='width: 73px; float: left;'><a href='http://www.apple.com/safari/download/' target='_blank'><img src='http://www.ie6nomore.com/files/theme/ie6nomore-safari.jpg' style='border: none;' alt='Get Safari 4'/></a></div>      <div style='float: left;'><a href='http://www.google.com/chrome' target='_blank'><img src='http://www.ie6nomore.com/files/theme/ie6nomore-chrome.jpg' style='border: none;' alt='Get Google Chrome'/></a></div>    </div>  </div>  <![endif]-->

        <header>
            <h1><a href="{{pages.homepage.get_absolute_url}}">{{settings.SITE_NAME}}</a></h1>
        </header>

        <nav>
            {% navigation pages.homepage.navigation section=pages.homepage %}
        </nav>

        <div>
            <article>
                {% if not pages.is_homepage %}
                    <nav id="nav-breadcrumbs">{% block breadcrumbs %}{% breadcrumbs %}{% endblock %}</nav>
                {% endif %}
                {% block header_group %}
                    <h1>{% block header %}{% header %}{% endblock %}</h1>
                {% endblock %}
                {% block content_primary %}{{pages.current.content.content_primary|html}}{% endblock %}
            </article>
            <aside>
                {% block content_secondary %}{% endblock %}
            </aside>
        </div>

        <footer>
            <p>© {% now "Y" %} Site owner.</p>
        </footer>

    </body>

</html>
